Index: net/url_request/url_request_redirect_job.h |
diff --git a/net/url_request/url_request_redirect_job.h b/net/url_request/url_request_redirect_job.h |
index bc10eeedeedde092a77d62b1dbdc0ed5e087d3e1..4a7f9a74b4a6ae366e793011afaad22247a54dac 100644 |
--- a/net/url_request/url_request_redirect_job.h |
+++ b/net/url_request/url_request_redirect_job.h |
@@ -10,10 +10,10 @@ |
class GURL; |
// A URLRequestJob that will redirect the request to the specified |
// URL. This is useful to restart a request at a different URL based |
// on the result of another job. |
-class URLRequestRedirectJob : public URLRequestJob { |
+class URLRequestRedirectJob : public net::URLRequestJob { |
public: |
// Constructs a job that redirects to the specified URL. |
URLRequestRedirectJob(net::URLRequest* request, GURL redirect_destination); |
@@ -10,10 +10,10 @@ |
class GURL; |
-// A URLRequestJob that will redirect the request to the specified |
+// A net::URLRequestJob that will redirect the request to the specified |
// URL. This is useful to restart a request at a different URL based |
// on the result of another job. |